@@ -9,7 +9,7 @@
 ## no critic (RequireUseStrict, RequireUseWarnings)
 package Riak::Light;
 {
-    $Riak::Light::VERSION = '0.070';
+    $Riak::Light::VERSION = '0.071';
 }
 ## use critic
 
@@ -21,6 +21,7 @@ use Types::Standard -types;
 use English qw(-no_match_vars );
 use Scalar::Util qw(blessed);
 use IO::Socket;
+use Socket qw(TCP_NODELAY IPPROTO_TCP);
 use Const::Fast;
 use JSON;
 use Carp;
@@ -89,6 +90,9 @@ sub _build_socket {
     croak "Error ($!), can't connect to $host:$port"
       unless defined $socket;
 
+    $socket->setsockopt( IPPROTO_TCP, TCP_NODELAY, 1 )
+      or croak "Cannot set tcp nodelay $! ($^E)";
+
     return $socket unless defined $self->timeout_provider;
 
     use Module::Load qw(load);
@@ -302,6 +306,10 @@ sub query_index {
     my $query_type = 0;    # eq
     ref $value_to_match
       and $query_type = 1;    # range
+
+    croak "query index in stream mode not supported"
+      if $extra_parameters->{stream};
+
     my $body = RpbIndexReq->encode(
         {   index  => $index,
             bucket => $bucket,
@@ -503,7 +511,7 @@ Riak::Light - Fast and lightweight Perl client for Riak
 
 =head1 VERSION
 
-version 0.070
+version 0.071
 
 =head1 SYNOPSIS
 
@@ -768,7 +776,7 @@ Based on the example in C<put>, here is how to query it:
     continuation => $continuation
    });
 
-  to fetch only the first 100 keys you can do this
+to fetch only the first 100 keys you can do this
 
   my $matching_keys = $client->query_index( 'bucket',  'field2_int', [ 40, 50], { max_results => 100 });
 
